Name:           tigervnc
Version:        1.13.1
%define subrel 8
Release:        %mkrel 2
Summary:	Viewer for the VNC remote display system
Group:		Networking/Remote access
License:        GPLv2+
URL:            http://www.tigervnc.com/
Source0:        https://github.com/TigerVNC/tigervnc/archive/v%{version}/%{name}-%{version}.tar.gz
Source1:        xvnc.service
Source2:        xvnc.socket
Source4:        HOWTO.md

Patch8:         tigervnc-getmaster.patch
# initially from openmdv
Patch12:        tigervnc-1.8.90-mga-buildir.patch
#Patches from fedora

# copied from debian
Patch30:	tigervnc-1.8.0-CVE-2014-8240.patch

# This is tigervnc-%%{version}/unix/xserver211.patch rebased on the latest xorg
Patch100:       tigervnc-xserver211.patch

BuildRequires:  x11-server-source
BuildRequires:  gettext-devel
BuildRequires:  pkgconfig(x11)
BuildRequires:  libxext-devel
BuildRequires:  x11-font-util
BuildRequires:  x11-util-macros
BuildRequires:  x11-xtrans-devel
BuildRequires:  mesagl-devel
BuildRequires:  libxkbfile-devel
BuildRequires:  libxfont2-devel
BuildRequires:  pixman-devel
BuildRequires:  openssl-devel
BuildRequires:  libpciaccess-devel
BuildRequires:  libpam-devel
BuildRequires:  libxtst-devel
BuildRequires:  gnutls-devel
BuildRequires:  imagemagick
BuildRequires:  nasm
BuildRequires:  java-devel
BuildRequires:  desktop-file-utils
BuildRequires:  jpackage-utils
BuildRequires:  fltk-devel
BuildRequires:  libtool
BuildRequires:  autoconf
BuildRequires:  libxi-devel
BuildRequires:  libxinerama-devel
BuildRequires:  freetype-devel
BuildRequires:  libxdmcp-devel
BuildRequires:  pam-devel
BuildRequires:  libjpeg-devel
BuildRequires:  cmake
BuildRequires:  libxrandr-devel
BuildRequires:  pkgconfig(libxcvt)

%description
Virtual Network Computing (VNC) is a remote display system which
allows you to view a computing 'desktop' environment not only on the
machine where it is running, but from anywhere on the Internet and
from a wide variety of machine architectures.  This package contains a
client which will allow you to connect to other desktops running a VNC
server.

#------------------------------------------------------------------------------

%package server

Summary: Server for the VNC remote display system
Group:   Networking/Remote access

Requires: vnc-server-common

%description server
The VNC system allows you to access the same desktop from a wide
variety of platforms.  This package is a TigerVNC server, allowing
others to access the desktop on your machine.

#------------------------------------------------------------------------------

%package server-module

Summary: Xorg module for the VNC remote display system
Group:   Networking/Remote access

Requires: x11-server-xorg

%description server-module
This package contains libvnc.so module to X server, allowing others
to access the desktop on your machine.

#------------------------------------------------------------------------------

%package java

Summary: Java viewer for the VNC remote display system
Group:   Networking/Remote access


# "TightVNC-specific" is not a typo, see the README file located inside the
# java source tree
%description java
This distribution is based on the standard VNC source and includes new
TightVNC-specific features and fixes, such as additional low-bandwidth
optimizations, major GUI improvements, and more.

There are three basic ways to use TigerVNC Java viewer:
  1. Running applet as part of TigerVNC server installation.
  2. Running applet hosted on a standalone Web server.
  3. Running the viewer as a standalone application.

#------------------------------------------------------------------------------

%prep
%setup -q

%patch12 -p1 -b .builddir

cp -r /usr/share/x11-server-source/* unix/xserver
pushd unix/xserver
for all in `find . -type f -perm -001`; do
        chmod -x "$all"
done
%patch100 -p1 -b .xserver211-rebased
popd

# libvnc.so: don't use unexported GetMaster function (bug #744881 again).
%patch8 -p1 -b .getmaster

%patch30 -p1 -b .CVE-2014-8240

# make pam_selinux.so optional
sed -i -e '/pam_selinux\.so/s/required/optional/g' unix/vncserver/tigervnc.pam

%build
%cmake
%cmake_build

pushd unix/xserver
rm -f configure
autoreconf -fiv
%configure  \
                --disable-xorg --disable-xnest --disable-xvfb --disable-dmx \
                --disable-xwin --disable-xephyr --disable-kdrive --disable-xwayland \
                --with-pic --disable-static \
                --with-default-font-path="catalogue:%{_sysconfdir}/X11/fontpath.d,built-ins" \
                --with-fontrootdir=%{_datadir}/X11/fonts \
                --with-xkb-output=%{_localstatedir}/lib/xkb \
                --enable-glx --disable-dri --enable-dri2 --disable-dri3  \
                --disable-unit-tests \
                --disable-config-hal \
                --disable-config-udev \
                --without-dtrace \
                --disable-devel-docs \
                --disable-selective-werror

%make_build
popd


# Build icons
pushd media
%cmake
%cmake_build
popd

# Build Java applet
pushd java
%cmake
JAVA_TOOL_OPTIONS="-Dfile.encoding=UTF8" \
%cmake_build
popd

%install
%cmake_install

%make_install -C unix/xserver/hw/vnc

# Install systemd unit file
install -m644 %{SOURCE1} %{buildroot}%{_unitdir}/xvnc@.service
install -m644 %{SOURCE2} %{buildroot}%{_unitdir}/xvnc.socket

# Install desktop stuff
mkdir -p %{buildroot}%{_iconsdir}/hicolor/{16x16,24x24,48x48}/apps

pushd media/icons
for s in 16 24 48; do
install -m644 tigervnc_$s.png %{buildroot}%{_iconsdir}/hicolor/${s}x$s/apps/tigervnc.png
done
popd

# Install a replacement for /usr/bin/vncserver which will tell the user to read the
# HOWTO.md file
cat <<EOF > %{buildroot}%{_bindir}/vncserver
#!/bin/bash
echo "vncserver has been replaced by a systemd unit."
echo "Please read /usr/share/doc/tigervnc/HOWTO.md for more information."
EOF
chmod +x %{buildroot}%{_bindir}/vncserver

install -m 644 %{SOURCE4} .

%find_lang %{name} %{name}.lang

# remove unwanted files
rm -f  %{buildroot}%{_libdir}/xorg/modules/extensions/libvnc.la

# Install Java applet

install -d -m 755 %{buildroot}%{_javadir}
install -d -m 755 %{buildroot}%{_datadir}/vnc/classes
pushd java/build

install -m 755 VncViewer.jar %{buildroot}%{_datadir}/vnc/classes/vncviewer-%{version}.jar
popd

pushd %{buildroot}%{_datadir}/vnc/classes
mv vncviewer-%{version}.jar %{buildroot}%{_javadir}
ln -s %{_javadir}/vncviewer-%{version}.jar VncViewer.jar
popd

pushd %{buildroot}%{_javadir}
ln -s vncviewer-%{version}.jar vncviewer.jar
ln -s vncviewer-%{version}.jar VncViewer.jar
popd

%files -f %{name}.lang
%doc README.rst HOWTO.md LICENCE.TXT
%license LICENCE.TXT
%{_bindir}/vncviewer
%{_iconsdir}/hicolor/*/apps/tigervnc.{png,svg}
%{_datadir}/applications/*.desktop
%{_metainfodir}/org.tigervnc.vncviewer.metainfo.xml
%{_mandir}/man1/vncviewer.1*

%files server
%doc HOWTO.md
%config(noreplace) %{_sysconfdir}/pam.d/tigervnc
%config(noreplace) %{_sysconfdir}/tigervnc/vncserver-config-defaults
%config(noreplace) %{_sysconfdir}/tigervnc/vncserver-config-mandatory
%config(noreplace) %{_sysconfdir}/tigervnc/vncserver.users
%{_unitdir}/vncserver@.service
%{_unitdir}/xvnc@.service
%{_unitdir}/xvnc.socket
%{_bindir}/vncconfig
%{_bindir}/vncpasswd
%{_bindir}/Xvnc
%{_bindir}/vncserver
%{_bindir}/x0vncserver
%{_sbindir}/vncsession
%{_libexecdir}/vncserver
%{_libexecdir}/vncsession-start
%{_mandir}/man1/Xvnc.1*
%{_mandir}/man1/vncpasswd.1*
%{_mandir}/man1/vncconfig.1*
%{_mandir}/man1/x0vncserver.1*
%{_mandir}/man8/vncserver.8*
%{_mandir}/man8/vncsession.8*

%files server-module
%{_libdir}/xorg/modules/extensions/libvnc.so

%files java
%{_javadir}/*.jar
%{_datadir}/vnc


%changelog
* Mon Jun 23 2025 ns80 <ns80> 1.13.1-2.8.mga9
+ Revision: 2194149
- rebuild for CVE-2025-4917[5-9], CVE-2025-49180 (mga#34381)
- rebuild for CVE-2025-2659[4-9] and CVE-2025-2660[01] (mga#34052)
- rebuild for CVE-2024-9632 (mga#33710)
- rebuild for possible double-free in ProcRenderAddGlyphs() (mga#33101)
- rebuild for CVE-2024-3108[0-3] (mga#33058)
- rebuild for CVE-2023-6816, CVE-2024-0229, CVE-2024-2188[56] and CVE-2024-040[89] (mga#32747)
- rebuild for CVE-2023-6377 and CVE-2023-6478 (mga#32625)
- rebuild for CVE-2023-5380 and CVE-2023-5367 (mga#32513)

* Wed Apr 05 2023 ns80 <ns80> 1.13.1-2.mga9
+ Revision: 1951485
- rebuild for CVE-2023-1393 (mga#31732)

* Tue Mar 14 2023 luigiwalser <luigiwalser> 1.13.1-1.mga9
+ Revision: 1948926
- 1.13.1
- rebase xserver211 patch

* Sat Feb 11 2023 daviddavid <daviddavid> 1.13.0-1.mga9
+ Revision: 1940112
- new version: 1.13.0
- rebase xserver211 patch

* Thu Feb 09 2023 ns80 <ns80> 1.12.0-4.mga9
+ Revision: 1939736
- rebuild for CVE-2023-0494 (mga#31523)

* Sat Jan 28 2023 wally <wally> 1.12.0-3.mga9
+ Revision: 1936647
- don't own hicolor icon dirs

* Tue Jan 10 2023 ns80 <ns80> 1.12.0-2.mga9
+ Revision: 1932103
- rebuild for recent x11-server security update (mga#31386)

* Thu May 12 2022 ns80 <ns80> 1.12.0-1.mga9
+ Revision: 1857717
- new version 1.12.0 (mga#30386)
+ umeabot <umeabot>
- Mageia 9 Mass Rebuild

* Sun Dec 06 2020 wally <wally> 1.11.0-4.mga8
+ Revision: 1653896
- make pam_selinux.so optional in pam configs (mga#27747)

* Mon Nov 30 2020 luigiwalser <luigiwalser> 1.11.0-3.mga8
+ Revision: 1650604
- remove invalid scriplets
- rebuild for nettle
+ tv <tv>
- package README.rst
- Add systemd unit file for xvnc (rhbz#891802)
- Enable Present extensions
- Don't disable Xinerama extension (upstream #147).

* Sat Sep 19 2020 tv <tv> 1.11.0-1.mga8
+ Revision: 1628819
- fix file list
- Add /usr/bin/vncserver file informing users to read the HOWTO.md file
+ ns80 <ns80>
- new version 1.11.0 (mga#27270)

* Sun Apr 12 2020 mrambo3501 <mrambo3501> 1.10.1-3.mga8
+ Revision: 1566979
- add patch to fix Invalid display size (mga#26118)

* Mon Mar 16 2020 daviddavid <daviddavid> 1.10.1-2.mga8
+ Revision: 1556859
- fix build with xserver 1.20.7
- use new cmake macros
+ umeabot <umeabot>
- Mageia 8 Mass Rebuild
+ wally <wally>
- replace deprecated %%configure2_5x

* Fri Dec 20 2019 kekepower <kekepower> 1.10.1-1.mga8
+ Revision: 1469065
- Update to version 1.10.1

* Sun Nov 24 2019 daviddavid <daviddavid> 1.10.0-1.mga8
+ Revision: 1462553
- new version: 1.10.0

* Tue Oct 01 2019 daviddavid <daviddavid> 1.9.0-4.mga8
+ Revision: 1448575
- rebuild for new nettle 3.5.1

* Mon Feb 18 2019 wally <wally> 1.9.0-3.mga7
+ Revision: 1368220
- build with xrandr

* Sun Sep 23 2018 umeabot <umeabot> 1.9.0-2.mga7
+ Revision: 1301410
- Mageia 7 Mass Rebuild

* Tue Jul 17 2018 daviddavid <daviddavid> 1.9.0-1.mga7
+ Revision: 1243915
- new version: 1.9.0

* Sat Jul 14 2018 daviddavid <daviddavid> 1.8.90-1.mga7
+ Revision: 1243653
- new version: 1.8.90
- rebase for xserver 1.20

* Sun Jun 04 2017 luigiwalser <luigiwalser> 1.8.0-1.mga6
+ Revision: 1106590
- rediff patch 30
- 1.8.0 (fixes CVE-2017-739[2-6] and CVE-2017-10207)
- remove upstreamed patches 1, 2, and 3

* Wed Jan 18 2017 luigiwalser <luigiwalser> 1.7.1-1.mga6
+ Revision: 1082406
- 1.7.1

* Fri Jan 13 2017 luigiwalser <luigiwalser> 1.7.0-2.mga6
+ Revision: 1081262
- add patch from fedora to fix -inetd not working (rhbz#1408724)

* Sun Jan 01 2017 luigiwalser <luigiwalser> 1.7.0-1.mga6
+ Revision: 1079134
- 1.7.0 (resync with fedora)
- sync rediffed CVE-2014-824[01] patches from debian

* Mon Jun 27 2016 pterjan <pterjan> 1.6.0-4.mga6
+ Revision: 1037755
- Use fPIC even on 32 bit arches

* Tue Apr 05 2016 tv <tv> 1.6.0-3.mga6
+ Revision: 998771
- rebuild for new xorgs source
- rename patches with their current name in FC

* Mon Jan 11 2016 luigiwalser <luigiwalser> 1.6.0-2.mga6
+ Revision: 921841
- rebuild for gnutls

* Fri Dec 25 2015 tv <tv> 1.6.0-1.mga6
+ Revision: 914660
- temporary disable -as-needed
- rediff patches
- add source URL
- drop merged patch 2
- add one patch from FC for xserver 1,18

* Fri Nov 20 2015 luigiwalser <luigiwalser> 1.5.0-4.mga6
+ Revision: 904671
- rediff patches from rhel to fix CVE-2014-8240 and CVE-2014-8241

* Wed Nov 18 2015 tv <tv> 1.5.0-3.mga6
+ Revision: 903930
- add one patch from FC for xserver 1,18

* Tue Sep 29 2015 barjac <barjac> 1.5.0-2.mga6
+ Revision: 884915
- really sync fd patches - sorry

* Mon Sep 28 2015 barjac <barjac> 1.5.0-1.mga6
+ Revision: 884385
- new version 1.5.0
- sync patches with Fedora
+ fwang <fwang>
- rebuild for new gnutls/nettle

* Mon Feb 16 2015 luigiwalser <luigiwalser> 1.3.1-6.mga5
+ Revision: 815012
- minor adjustment to xserver patch in WaitFor.c
- resync patch14 from fedora to fix build with x11-server 1.16.x

* Wed Nov 05 2014 tv <tv> 1.3.1-5.mga5
+ Revision: 795719
- Drop no longer needed BuildRequires on java-rpmbuild

* Wed Oct 15 2014 umeabot <umeabot> 1.3.1-4.mga5
+ Revision: 747511
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 1.3.1-3.mga5
+ Revision: 689882
- Mageia 5 Mass Rebuild

* Tue Aug 26 2014 luigiwalser <luigiwalser> 1.3.1-2.mga5
+ Revision: 668397
- spec and patch updates from fedora to fix build with xorg 1.16
- rediff patch from fedora to replace upstream xserver114.patch

* Sun Apr 06 2014 bersuit <bersuit> 1.3.1-1.mga5
+ Revision: 612276
- Update to 1.3.1 upstream version
 - Add patch to xserver 1.15
 - Disable wayland, present & dri3 in configure

* Tue Oct 22 2013 umeabot <umeabot> 1.3.0-2.mga4
+ Revision: 542337
- Mageia 4 Mass Rebuild

* Wed Oct 09 2013 bersuit <bersuit> 1.3.0-1.mga4
+ Revision: 494273
- Update to new upstream version 1.3.0
-Synchronized with fedora.
-Add Fedora bug-fixing patch
-Add OpenMandriva build patch
-fix #mga10181: changes the java classes path /usr/share/tigervnc/classes to /usr/share/vnc/classes
-Rebuilt xorg110 & xorg111 fedora patch
-Added fedora patch to xorg112 & xorg113
-Added fedora patch to latest Java 7
+ umeabot <umeabot>
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Sun May 13 2012 pterjan <pterjan> 1.1.0-3.mga2
+ Revision: 235645
- Revert untested/incomplete/hard to use/breaking updates systemd integration to make package installable again (mga#4777)

* Sat Apr 28 2012 tmb <tmb> 1.1.0-2.mga2
+ Revision: 233875
- Require rpm-helper >= 0.24.8-1 for systemd support
+ fwang <fwang>
- there is no workaround for ldflags

* Sat Dec 10 2011 dmorgan <dmorgan> 1.1.0-1.mga2
+ Revision: 180037
- Disable unit-tests
- New version 1.1.0

* Tue Sep 06 2011 dmorgan <dmorgan> 1.0.90-0.201106280527.2.mga2
+ Revision: 138995
- Add desktop-file-utils as buildRequire
- Add desktop-file-install as buildRequire
+ misc <misc>
- do not hardcode the name of the distribution anymore
- remove old obsoletes/provides
+ fwang <fwang>
- new snapshot 20110628
- build with xserver 1.10
- rebuild for new gnutls

* Tue Feb 22 2011 dmorgan <dmorgan> 1.0.90-0.201012034210.6.mga1
+ Revision: 57070
- Remove Encoding from desktop file
- Fix bugzilla URL
- imported package tigervnc


* Thu Jan 13 2011 Paulo Ricardo Zanoni <pzanoni@mandriva.com> 1.0.90-0.201012034210.6mdv2011.0
+ Revision: 631010
- Obsolete RealVNC packages

* Tue Dec 28 2010 Paulo Ricardo Zanoni <pzanoni@mandriva.com> 1.0.90-0.201012034210.5mdv2011.0
+ Revision: 625668
- BR java-devel
- Add -java package
- Use %%makeinstall_std

* Thu Dec 23 2010 Paulo Ricardo Zanoni <pzanoni@mandriva.com> 1.0.90-0.201012034210.4mdv2011.0
+ Revision: 624170
- Remove sysconfig, initscript and require vnc-server-common
- Fix dekstop file categories
- Update summaries, descriptions, profiles, conflicts and groups (part of vnc
  packages standardization)

* Thu Dec 16 2010 Paulo Ricardo Zanoni <pzanoni@mandriva.com> 1.0.90-0.201012034210.3mdv2011.0
+ Revision: 622330
- Add patches to fix problems with scrollbars.

* Wed Dec 08 2010 Paulo Ricardo Zanoni <pzanoni@mandriva.com> 1.0.90-0.201012034210.2mdv2011.0
+ Revision: 616320
- Add initscript file
- Add sysconfig/vncservers file
- Use configure2_5x
- Use system jpeg
- Remove unrecognized configure options
- Don't chmod files copied by x11-server-source

* Mon Dec 06 2010 Paulo Ricardo Zanoni <pzanoni@mandriva.com> 1.0.90-0.201012034210.1mdv2011.0
+ Revision: 612395
- Update to newer revision
- Use xserver19 patch
- Fix linking

* Wed May 05 2010 Paulo Ricardo Zanoni <pzanoni@mandriva.com> 1.0.90-0.201004234031.2mdv2010.1
+ Revision: 542633
- Remove sed in Makefile.am (was breaking libvnc.so)
- Add URL tag

* Fri Apr 23 2010 Paulo Ricardo Zanoni <pzanoni@mandriva.com> 1.0.90-0.201004234031.1mdv2010.1
+ Revision: 538366
- import tigervnc

